@@ -2,7 +2,7 @@ package Catmandu::Store::MongoDB;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0403';
+our $VERSION = '0.05';
 
 use Moo;
 use Catmandu::Store::MongoDB::Bag;
@@ -113,11 +113,16 @@ Catmandu::Store::MongoDB - A searchable store backed by MongoDB
     my $hits = $store->bag->search(query => '{"name":"Patrick"}');
     my $hits = $store->bag->search(query => '{"name":"Patrick"}' , sort => { age => -1} );
     my $hits = $store->bag->search(query => {name => "Patrick"} , start => 0 , limit => 100);
-    
+    my $hits = $store->bag->search(query => {name => "Patrick"} , fields => {_id => 0, name => 1});
+
     my $next_page = $hits->next_page;
     my $hits = $store->bag->search(query => '{"name":"Patrick"}' , page => $next_page);
 
     my $iterator = $store->bag->searcher(query => {name => "Patrick"});
+    my $iterator = $store->bag->searcher(query => {name => "Patrick"}, fields => {_id => 0, name => 1});
+
+    # Catmandu::Store::MongoDB supports CQL...
+    my $hits = $store->bag->search(cql_query => 'name any "Patrick"');
 
 =head1 DESCRIPTION
 
@@ -128,18 +133,68 @@ Databases also have compartments (e.g. tables) called Catmandu::Bag-s.
 =head1 DEPRECATION NOTICE
 
 The following connection parameters are depreacted and will be removed in a future version of this module:
-    
+
     - connect_retry
     - connect_retry_sleep
 
 =head1 METHODS
 
-=head2 new(database_name => $name , %opts )
+=head2 new(database_name => $name, %connectio_opts)
 
-Create a new Catmandu::Store::MongoDB store with name $name. Optionally 
-provide connection parameters (see L<MongoDB::MongoClient> for possible 
+=head2 new(database_name => $name , bags => { data => { cql_mapping => $cql_mapping } })
+
+Create a new Catmandu::Store::MongoDB store with name $name. Optionally
+provide connection parameters (see L<MongoDB::MongoClient> for possible
 options).
 
+The store supports CQL searches when a cql_mapping is provided. This hash
+contains a translation of CQL fields into MongoDB searchable fields.
+
+ # Example mapping
+ $cql_mapping = {
+     indexes => {
+          title => {
+            op => {
+              'any'   => 1 ,
+              'all'   => 1 ,
+              '='     => 1 ,
+              '<>'    => 1 ,
+              'exact' => {field => [qw(mytitle.exact myalttitle.exact)]}
+            } ,
+            sort  => 1,
+            field => 'mytitle',
+            cb    => ['Biblio::Search', 'normalize_title']
+          }
+    }
+ }
+
+The CQL mapping above will support for the 'title' field the CQL operators:
+ any, all, =, <> and exact.
+
+The 'title' field will be mapped into the MongoDB field 'mytitle',
+except for the 'exact' operator. In case of 'exact' both the
+'mytitle.exact' and 'myalttitle.exact' fields will be searched.
+
+The CQL mapping allows for sorting on the 'title' field. If, for instance, we
+would like to use a special MongoDB field for sorting we could have written
+"sort => { field => 'mytitle.sort' }".
+
+The CQL has an optional callback field 'cb' which contains a reference to subroutines
+to rewrite or augment the search query. In this case, in the Biblio::Search package
+contains a normalize_title subroutine which returns a string or an ARRAY of string
+with augmented title(s). E.g.
+
+    package Biblio::Search;
+
+    sub normalize_title {
+       my ($self,$title) = @_;
+       # delete all bad characters
+       my $new_title =~ s{[^A-Z0-9]+}{}g;
+       $new_title;
+    }
+
+    1;
+
 =head2 bag($name)
 
 Create or retieve a bag with name $name. Returns a L<Catmandu::Bag>.
@@ -156,6 +211,12 @@ Return a L<MongoDB::Database> instance.
 
 Delete the store and all it's bags.
 
+=head1 Search
+
+Search the database: see L<Catmandu::Searchable>. This module supports an additional search parameter:
+
+    - fields => { <field> => <0|1> } : limit fields to return from a query (see L<MongoDB Tutorial|https://docs.mongodb.org/manual/tutorial/project-fields-from-query-results/>)
+
 =head1 SEE ALSO
 
 L<Catmandu::Bag>, L<Catmandu::Searchable> , L<MongoDB::MongoClient>
