@@ -2,13 +2,15 @@ package Catmandu::Store::MongoDB::Bag;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0403';
+our $VERSION = '0.05';
 
 use Catmandu::Util qw(:is);
 use Catmandu::Store::MongoDB::Searcher;
 use Catmandu::Hits;
 use JSON::MaybeXS qw(decode_json);
 use Moo;
+use Data::Dumper;
+use Catmandu::Store::MongoDB::CQL;
 use namespace::clean;
 
 with 'Catmandu::Bag';
@@ -21,6 +23,8 @@ has collection => (
     builder => '_build_collection',
 );
 
+has cql_mapping => (is => 'ro');
+
 sub _build_collection {
     my ($self) = @_;
     $self->store->database->get_collection($self->name);
@@ -161,11 +165,16 @@ sub search {
     my $start = $args{start};
     my $limit = $args{limit};
     my $bag   = $args{reify};
+    my $fields = $args{fields};
 
     my $cursor = $self->collection->find($query)->skip($start)->limit($limit);
     if ($bag) { # only retrieve _id
         $cursor->fields({})
     }
+    elsif ($fields) { # only retrieve specified fields
+        $cursor->fields($fields);
+    }
+
     if (my $sort =  $args{sort}) {
         $cursor->sort($sort);
     }
@@ -189,11 +198,49 @@ sub searcher {
 }
 
 sub translate_sru_sortkeys {
-    Catmandu::NotImplemented->throw;
+    my ($self, $sortkeys) = @_;
+    $self->log->debug("translating sort_keys: $sortkeys");
+    my $keys =
+      [ grep { defined $_ } map { $self->_translate_sru_sortkey($_) } split /\s+/, $sortkeys ];
+    my $mongo_sort = [];
+    # flatten sort keys
+    for (@$keys) {
+        push @$mongo_sort , @$_;
+    }
+    $self->log->debug("mongo_sort : " . Dumper($mongo_sort));
+    $mongo_sort;
+}
+
+sub _translate_sru_sortkey {
+    my ($self, $sortkey) = @_;
+    my ($field, $schema, $asc) = split /,/, $sortkey;
+    $field || return;
+    ($asc && ($asc == 1 || $asc == -1)) || return;
+    if (my $map = $self->cql_mapping) {
+        $field = lc $field;
+        $field =~ s/(?<=[^_])_(?=[^_])//g if $map->{strip_separating_underscores};
+        $map = $map->{indexes} || return;
+        $map = $map->{$field}  || return;
+        $map->{sort} || return;
+        if (ref $map->{sort} && $map->{sort}{field}) {
+            $field = $map->{sort}{field};
+        } elsif (ref $map->{field}) {
+            $field = $map->{field}->[0];
+        } elsif ($map->{field}) {
+            $field = $map->{field};
+        }
+    }
+    # Use a bad trick to force $asc interpreted as an integer
+    [ $field => $asc + 0 ];
 }
 
 sub translate_cql_query {
-    Catmandu::NotImplemented->throw;
+    my($self,$query) = @_;
+    $self->log->debug("translating cql: $query");
+    my $mongo_query =
+     Catmandu::Store::MongoDB::CQL->new(mapping => $self->cql_mapping)->parse($query);
+    $self->log->debug("mongo_query : " . Dumper($mongo_query));
+    $mongo_query;
 }
 
 # assume a string query is a JSON encoded MongoDB query
@@ -212,3 +259,18 @@ sub drop {
 
 __END__
 
+=pod
+
+=head1 NAME
+
+Catmandu::Store::MongoDB::Bag - Catmandu::Bag implementation for MongoDB
+
+=head1 DESCRIPTION
+
+This class isn't normally used directly. Instances are constructed using the store's C<bag> method.
+
+=head1 SEE ALSO
+
+L<Catmandu::Bag>, L<Catmandu::Searchable>
+
+=cut
