@@ -2,7 +2,7 @@ package Catmandu::Store::MongoDB::Searcher;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0403';
+our $VERSION = '0.05';
 
 use Moo;
 use namespace::clean;
@@ -15,12 +15,14 @@ has start => (is => 'ro', required => 1);
 has limit => (is => 'ro', required => 1);
 has total => (is => 'ro');
 has sort  => (is => 'ro');
+has fields => (is => 'ro');
 
 sub generator {
     my ($self) = @_;
     sub {
         state $cursor = do {
             my $c = $self->bag->collection->find($self->query);
+            $c->fields($self->fields) if defined $self->fields;
             # limit is unused because the perl driver doesn't expose batchSize
             $c->limit($self->total) if defined $self->total;
             $c->sort($self->sort) if defined $self->sort;
@@ -41,6 +43,7 @@ sub slice { # TODO constrain total?
         limit => $self->limit,
         total => $total,
         sort  => $self->sort,
+        fields => $self->fields,
     );
 }
 
